@@ -1,5 +1,5 @@
 
-from typing import Literal, Optional
+from typing import List, Literal, Optional
 
 from pydantic import BaseModel, HttpUrl, Json
 
@@ -7,14 +7,12 @@ from pydantic import BaseModel, HttpUrl, Json
 class ResolveRequest(BaseModel):
     sub : HttpUrl
     anchor : HttpUrl
-    iss: Optional[HttpUrl]
     format :Literal["json"]
 
     def example():  # pragma: no cover
         return ResolveRequest(
             sub= "http://127.0.0.1:8000/oidc/rp/",
             anchor= "http://127.0.0.1:8000/",
-            iss= "http://127.0.0.1:8000/",
             format= "json",
         )
 
@@ -26,6 +24,7 @@ class ResolveResponse(BaseModel):
     exp: int
     trust_marks : Json
     metadata: Json
+    trust_chain: List
 
 
 class ResolveHeader(BaseModel):
